% Auto-generated chapter 21 for tirmidhi
% Hadiths in this chapter: 72

\hadithdefcmd{tirmidhi}{1548}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِي الْبَخْتَرِيِّ، أَنَّ جَيْشًا، مِنْ جُيُوشِ الْمُسْلِمِينَ كَانَ أَمِيرَهُمْ سَلْمَانُ الْفَارِسِيُّ حَاصَرُوا قَصْرًا مِنْ قُصُورِ فَارِسَ فَقَالُوا يَا أَبَا عَبْدِ اللَّهِ أَلاَ نَنْهَدُ إِلَيْهِمْ قَالَ دَعُونِي أَدْعُهُمْ كَمَا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَدْعُوهُمْ ‏.‏ فَأَتَاهُمْ سَلْمَانُ فَقَالَ لَهُمْ إِنَّمَا أَنَا رَجُلٌ مِنْكُمْ فَارِسِيٌّ تَرَوْنَ الْعَرَبَ يُطِيعُونَنِي فَإِنْ أَسْلَمْتُمْ فَلَكُمْ مِثْلُ الَّذِي لَنَا وَعَلَيْكُمْ مِثْلُ الَّذِي عَلَيْنَا وَإِنْ أَبَيْتُمْ إِلاَّ دِينَكُمْ تَرَكْنَاكُمْ عَلَيْهِ وَأَعْطُونَا الْجِزْيَةَ عَنْ يَدٍ وَأَنْتُمْ صَاغِرُونَ ‏.‏ قَالَ وَرَطَنَ إِلَيْهِمْ بِالْفَارِسِيَّةِ وَأَنْتُمْ غَيْرُ مَحْمُودِينَ ‏.‏ وَإِنْ أَبَيْتُمْ نَابَذْنَاكُمْ عَلَى سَوَاءٍ ‏.‏ قَالُوا مَا نَحْنُ بِالَّذِي نُعْطِي الْجِزْيَةَ وَلَكِنَّا نُقَاتِلُكُمْ ‏.‏ فَقَالُوا يَا أَبَا عَبْدِ اللَّهِ أَلاَ نَنْهَدُ إِلَيْهِمْ قَالَ لاَ ‏.‏ فَدَعَاهُمْ ثَلاَثَةَ أَيَّامٍ إِلَى مِثْلِ هَذَا ثُمَّ قَالَ انْهَدُوا إِلَيْهِمْ ‏.‏ قَالَ فَنَهَدْنَا إِلَيْهِمْ فَفَتَحْنَا ذَلِكَ الْقَصْرَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ بُرَيْدَةَ وَالنُّعْمَانِ بْنِ مُقَرِّنٍ وَابْنِ عُمَرَ وَابْنِ عَبَّاسٍ ‏.‏ وَحَدِيثُ سَلْمَانَ حَدِيثٌ حَسَنٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَطَاءِ بْنِ السَّائِبِ ‏.‏ وَسَمِعْتُ مُحَمَّدًا يَقُولُ أَبُو الْبَخْتَرِيِّ لَمْ يُدْرِكْ سَلْمَانَ لأَنَّهُ لَمْ يُدْرِكْ عَلِيًّا وَسَلْمَانُ مَاتَ قَبْلَ عَلِيٍّ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم إِلَى هَذَا وَرَأَوْا أَنْ يُدْعَوْا قَبْلَ الْقِتَالِ وَهُوَ قَوْلُ إِسْحَاقَ بْنِ إِبْرَاهِيمَ قَالَ إِنْ تُقُدِّمَ إِلَيْهِمْ فِي الدَّعْوَةِ فَحَسَنٌ يَكُونُ ذَلِكَ أَهْيَبَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ لاَ دِعْوَةَ الْيَوْمَ ‏.‏ وَقَالَ أَحْمَدُ لاَ أَعْرِفُ الْيَوْمَ أَحَدًا يُدْعَى ‏.‏ وَقَالَ الشَّافِعِيُّ لاَ يُقَاتَلُ الْعَدُوُّ حَتَّى يُدْعَوْا إِلاَّ أَنْ يَعْجَلُوا عَنْ ذَلِكَ فَإِنْ لَمْ يَفْعَلْ فَقَدْ بَلَغَتْهُمُ الدَّعْوَةُ ‏.‏\hadithno{1548}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Al-Bakhtari:"An Army from the armies of the Muslims, whose commander was Salman Al-Farisi, besieged one of the Persian castles. They said: 'O Abu 'Abdullah! Should we charge them?' He said: 'Leave me to call them (to Islam) as I heard the Messenger of Allah (ﷺ) call them.' So Salman went to them and said: 'I am only a man from among you, a Persian, and you see that the Arabs obey me. If you become Muslims then you will have the likes of what we have, and from you will be required that which is required from us. If you refuse, and keep your religion, then we will leave you to it, and you will give us the Jizyah from your hands while you are submissive.' He said to them in Persian: 'And you are other than praiseworthy and if you refuse then we will equally resist you.' They said: 'We will not give you the Jizyah, we will fight you instead.' So they said: 'O Abu 'Abdullah! Should we charge them?' He said: 'No.'" He said: "So for three days he called them to the same (things), and then he said: 'Charge them.'" He said: "So we charged them, and we conquered the castle}}
\hadithdefcmd{tirmidhi}{1549}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى الْعَدَنِيُّ الْمَكِّيُّ، - وَيُكْنَى بِأَبِي عَبْدِ اللَّهِ الرَّجُلُ الصَّالِحُ هُوَ ابْنُ أَبِي عُمَرَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ عَنْ عَبْدِ الْمَلِكِ بْنِ نَوْفَلِ بْنِ مُسَاحِقٍ عَنِ ابْنِ عِصَامٍ الْمُزَنِيِّ عَنْ أَبِيهِ وَكَانَتْ لَهُ صُحْبَةٌ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا بَعَثَ جَيْشًا أَوْ سَرِيَّةً يَقُولُ لَهُمْ ‏ "‏ إِذَا رَأَيْتُمْ مَسْجِدًا أَوْ سَمِعْتُمْ مُؤَذِّنًا فَلاَ تَقْتُلُوا أَحَدًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَهُوَ حَدِيثُ ابْنِ عُيَيْنَةَ ‏.‏\hadithno{1549}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Asim Al-Muzani:From his father and he was a Companion who said: "When the Messenger of Allah (ﷺ) dispatched any army or battalion, he would say to them: 'If you see a Masjid, or hear someone calling the Adhan, then do not kill anyone}}
\hadithdefcmd{tirmidhi}{1550}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنِي مَالِكُ بْنُ أَنَسٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ خَرَجَ إِلَى خَيْبَرَ أَتَاهَا لَيْلاً وَكَانَ إِذَا جَاءَ قَوْمًا بِلَيْلٍ لَمْ يُغِرْ عَلَيْهِمْ حَتَّى يُصْبِحَ فَلَمَّا أَصْبَحَ خَرَجَتْ يَهُودُ بِمَسَاحِيهِمْ وَمَكَاتِلِهِمْ فَلَمَّا رَأَوْهُ قَالُوا مُحَمَّدٌ وَافَقَ وَاللَّهِ مُحَمَّدٌ الْخَمِيسَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُ أَكْبَرُ خَرِبَتْ خَيْبَرُ إِنَّا إِذَا نَزَلْنَا بِسَاحَةِ قَوْمٍ فَسَاءَ صَبَاحُ الْمُنْذَرِينَ ‏"‏ ‏.‏\hadithno{1550}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Anas:"When the Messenger of Allah (ﷺ) set out for Khaibar, he approached it at night and when he came to a people during the night, he would not attack them until morning. So when the morning came, the Jews came out with their shovels and baskets, then when they saw him, they said: 'Muhammad! By Allah Muhammad has come with the Khamis (an army).' So the Messenger of Allah (ﷺ) said: 'Allahu Akbar! Khaibar is destroyed, for whenever we approach the land of people - then what an evil morning for those who have been warned}}
\hadithdefcmd{tirmidhi}{1551}{حَدَّثَنَا قُتَيْبَةُ، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنْ أَبِي طَلْحَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا ظَهَرَ عَلَى قَوْمٍ أَقَامَ بِعَرْصَتِهِمْ ثَلاَثًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَحَدِيثُ حُمَيْدٍ عَنْ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَخَّصَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ فِي الْغَارَةِ بِاللَّيْلِ وَأَنْ يَبِيتُوا وَكَرِهَهُ بَعْضُهُمْ ‏.‏ وَقَالَ أَحْمَدُ وَإِسْحَاقُ لاَ بَأْسَ أَنْ يُبَيَّتَ الْعَدُوُّ لَيْلاً ‏.‏ وَمَعْنَى قَوْلِهِ وَافَقَ مُحَمَّدٌ الْخَمِيسَ يَعْنِي بِهِ الْجَيْشَ ‏.‏\hadithno{1551}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Abu Talhah:"When the Prophet (ﷺ) overtook a people he would stay at the outskirts of their city for three nights}}
\hadithdefcmd{tirmidhi}{1552}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَرَّقَ نَخْلَ بَنِي النَّضِيرِ وَقَطَعَ وَهِيَ الْبُوَيْرَةُ فَأَنْزَلَ اللَّهُ ‏:‏ ‏(‏ مَا قَطَعْتُمْ مِنْ لِينَةٍ أَوْ تَرَكْتُمُوهَا قَائِمَةً عَلَى أُصُولِهَا فَبِإِذْنِ اللَّهِ وَلِيُخْزِيَ الْفَاسِقِينَ ‏)‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ ذَهَبَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ إِلَى هَذَا وَلَمْ يَرَوْا بَأْسًا بِقَطْعِ الأَشْجَارِ وَتَخْرِيبِ الْحُصُونِ ‏.‏ وَكَرِهَ بَعْضُهُمْ ذَلِكَ وَهُوَ قَوْلُ الأَوْزَاعِيِّ ‏.‏ قَالَ الأَوْزَاعِيُّ وَنَهَى أَبُو بَكْرٍ الصِّدِّيقُ يَزِيدَ أَنْ يَقْطَعَ شَجَرًا مُثْمِرًا أَوْ يُخَرِّبَ عَامِرًا وَعَمِلَ بِذَلِكَ الْمُسْلِمُونَ بَعْدَهُ ‏.‏ وَقَالَ الشَّافِعِيُّ لاَ بَأْسَ بِالتَّحْرِيقِ فِي أَرْضِ الْعَدُوِّ وَقَطْعِ الأَشْجَارِ وَالثِّمَارِ ‏.‏ وَقَالَ أَحْمَدُ وَقَدْ تَكُونُ فِي مَوَاضِعَ لاَ يَجِدُونَ مِنْهُ بُدًّا فَأَمَّا بِالْعَبَثِ فَلاَ تُحَرَّقُ ‏.‏ وَقَالَ إِسْحَاقُ التَّحْرِيقُ سُنَّةٌ إِذَا كَانَ أَنْكَى فِيهِمْ ‏.‏\hadithno{1552}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Umar:"The Messenger of Allah (ﷺ) burnt the palm trees of Bani Nadir and cut them down at Al-Buwairah. So Allah revealed: Whatever you cut down of their palm trees, or you left them standing on their trunks, then it was by the permission of Allah, and in the order to disgrace the rebellious.(59:)}}
\hadithdefcmd{tirmidhi}{1553}{\hadithno{1553}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1554}{\hadithno{1554}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1555}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى الأَزْدِيُّ الْبَصْرِيُّ، وَأَبُو عَمَّارٍ وَغَيْرُ وَاحِدٍ قَالُوا حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، عَنْ أَبِيهِ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَيْرُ الصَّحَابَةِ أَرْبَعَةٌ وَخَيْرُ السَّرَايَا أَرْبَعُمِائَةٍ وَخَيْرُ الْجُيُوشِ أَرْبَعَةُ آلاَفٍ وَلاَ يُغْلَبُ اثْنَا عَشَرَ أَلْفًا مِنْ قِلَّةٍ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ يُسْنِدُهُ كَبِيرُ أَحَدٍ غَيْرُ جَرِيرِ بْنِ حَازِمٍ وَإِنَّمَا رُوِيَ هَذَا الْحَدِيثُ عَنِ الزُّهْرِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏ وَقَدْ رَوَاهُ حِبَّانُ بْنُ عَلِيٍّ الْعَنَزِيُّ عَنْ عُقَيْلٍ عَنِ الزُّهْرِيِّ عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَاهُ اللَّيْثُ بْنُ سَعْدٍ عَنْ عُقَيْلٍ عَنِ الزُّهْرِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏\hadithno{1555}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas: That the Messenger of Allah (ﷺ) said: "The best companions are four, the best Saraya (military unit) is four hundred, the best army is four thousand, and twelve thousand will not be beaten due to being too few." This Hadith is Hasan Gharib, it was not narrated with a chain by anyone important besides Jarir bin Hazim, and this Hadith was only reported from Az-Zuhri, from the Prophet (ﷺ) in Mursal form. Hibban bin 'Ali Al-'Anazi reported it from 'Uqail, from Az-Zuhri, from 'Ubaidullah, from 'Ibn Abbas, from the Prophet (ﷺ), and Al-Laith bin Sa'd reported it from Sa'd, from 'Uqail, from Az-Zuhri, from the Prophet (ﷺ) in the Mursal form}}
\hadithdefcmd{tirmidhi}{1556}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ بْنِ هُرْمُزَ، أَنَّ نَجْدَةَ الْحَرُورِيَّ، كَتَبَ إِلَى ابْنِ عَبَّاسٍ يَسْأَلُهُ هَلْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَغْزُو بِالنِّسَاءِ وَهَلْ كَانَ يَضْرِبُ لَهُنَّ بِسَهْمٍ فَكَتَبَ إِلَيْهِ ابْنُ عَبَّاسٍ كَتَبْتَ إِلَىَّ تَسْأَلُنِي هَلْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَغْزُو بِالنِّسَاءِ وَكَانَ يَغْزُو بِهِنَّ فَيُدَاوِينَ الْمَرْضَى وَيُحْذَيْنَ مِنَ الْغَنِيمَةِ وَأَمَّا يُسْهِمُ فَلَمْ يَضْرِبْ لَهُنَّ بِسَهْمٍ ‏.‏ وَفِي الْبَابِ عَنْ أَنَسٍ وَأُمِّ عَطِيَّةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَالشَّافِعِيِّ ‏.‏ وَقَالَ بَعْضُهُمْ يُسْهَمُ لِلْمَرْأَةِ وَالصَّبِيِّ ‏.‏ وَهُوَ قَوْلُ الأَوْزَاعِيِّ قَالَ الأَوْزَاعِيُّ وَأَسْهَمَ النَّبِيُّ صلى الله عليه وسلم لِلصِّبْيَانِ بِخَيْبَرَ وَأَسْهَمَتْ أَئِمَّةُ الْمُسْلِمِينَ لِكُلِّ مَوْلُودٍ وُلِدَ فِي أَرْضِ الْحَرْبِ ‏.‏ قَالَ الأَوْزَاعِيُّ وَأَسْهَمَ النَّبِيُّ صلى الله عليه وسلم لِلنِّسَاءِ بِخَيْبَرَ وَأَخَذَ بِذَلِكَ الْمُسْلِمُونَ بَعْدَهُ ‏.‏ حَدَّثَنَا بِذَلِكَ عَلِيُّ بْنُ خَشْرَمٍ حَدَّثَنَا عِيسَى بْنُ يُونُسَ عَنِ الأَوْزَاعِيِّ بِهَذَا ‏.‏ وَمَعْنَى قَوْلِهِ وَيُحْذَيْنَ مِنَ الْغَنِيمَةِ يَقُولُ يُرْضَخُ لَهُنَّ بِشَيْءٍ مِنَ الْغَنِيمَةِ يُعْطَيْنَ شَيْئًا ‏.‏\hadithno{1556}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Yazid bin Hurmuz: That Najdah Al-Haruri wrote to Ibn 'Abbas asking if the Messenger of Allah (ﷺ) would fight along with women, and if he would fix a share of the spoils of war for them. Ibn 'Abbas wrote to him: "You wrote to me asking me if the Messenger of Allah (ﷺ) would fight along with women. He did fight along with them, as they would treat the wounded. They received something from the spoils of war, but as for their share, then he did not fix a share for them." There is something on this topic from Anas and Umm 'Atiyyah. This Hadith is Hasan Sahih. This is acted upon according to most of the people of knowledge. It is the view of Sufyan Ath-Thawri and Ash-Shafi'i. Some of them said that a share is given to the woman and the boy, and this is the view of Al-Awza'i. Al-Awza'i said: The Prophet (ﷺ) gave a portion to the boys at Khaibar, and the Aimmah of the Muslims gave a portion to every child born in the land of war." Al-Awza'i said: "The Prophet (ﷺ) gave a portion to the women at Khaibar, and that was followed by the Muslims after him." This was narrated to us by 'Ali bin Khashram (who said): "'Eisa bin Yunus narrated this to us from Al-Awza'i." The meaning of his saying: "They received something from the spoils of war" it is said that he conferred something on them (the women) from the spoils of war}}
\hadithdefcmd{tirmidhi}{1557}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ مُحَمَّدِ بْنِ زَيْدٍ، عَنْ عُمَيْرٍ، مَوْلَى آبِي اللَّحْمِ قَالَ شَهِدْتُ خَيْبَرَ مَعَ سَادَتِي فَكَلَّمُوا فِيَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَعْلَمُوهُ أَنِّي مَمْلُوكٌ ‏.‏ قَالَ فَأَمَرَ بِي فَقُلِّدْتُ السَّيْفَ فَإِذَا أَنَا أَجُرُّهُ فَأَمَرَ لِي بِشَيْءٍ مِنْ خُرْثِيِّ الْمَتَاعِ وَعَرَضْتُ عَلَيْهِ رُقْيَةً كُنْتُ أَرْقِي بِهَا الْمَجَانِينَ فَأَمَرَنِي بِطَرْحِ بَعْضِهَا وَحَبْسِ بَعْضِهَا ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ أَنْ لاَ يُسْهَمَ لِلْمَمْلُوكِ وَلَكِنْ يُرْضَخُ لَهُ بِشَيْءٍ ‏.‏ وَهُوَ قَوْلُ الثَّوْرِيِّ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1557}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Umair, the freed slave of Abil-Lahm: "I participated at Khaibar with my masters. They spoke about me to the Messenger of Allah (ﷺ) and told him that I was a slave." He said: "So he ordered me to take up the sword, and I found myself dragging it, so he ordered that I be given something from the goods. I presented a Ruqyah that I used to treat the possessed with, so he ordered me leave some of it and keep some of it." There is something on this topic from Ibn 'Abbas. This Hadith is Hasan Sahih. This is acted upon according to the some of the people of knowledge. A complete portion is not given to slave, but something is conferred upon him. This is the view of Ath-Thawri, Ash-Shafi'i, Ahmad, and Ishaq}}
\hadithdefcmd{tirmidhi}{1558}{\hadithno{1558}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif Isnaad}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1559}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، حَدَّثَنَا بُرَيْدُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي بُرْدَةَ، عَنْ جَدِّهِ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَدِمْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فِي نَفَرٍ مِنَ الأَشْعَرِيِّينَ خَيْبَرَ فَأَسْهَمَ لَنَا مَعَ الَّذِينَ افْتَتَحُوهَا ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ قَالَ الأَوْزَاعِيُّ مَنْ لَحِقَ بِالْمُسْلِمِينَ قَبْلَ أَنْ يُسْهَمَ لِلْخَيْلِ أُسْهِمَ لَهُ ‏.‏ وَبُرَيْدٌ يُكْنَى أَبَا بُرَيْدَةَ وَهُوَ ثِقَةٌ وَرَوَى عَنْهُ سُفْيَانُ الثَّوْرِيُّ وَابْنُ عُيَيْنَةَ وَغَيْرُهُمَا ‏.‏\hadithno{1559}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Abu Musa: "I arrived upon the Messenger of Allah (ﷺ) at Khaibar along with a group of the Ash'ari tribe. He gave us shared along with those that conquered it." This Hadith is Hasan Sahih Gharib. This is acted upon according to some of the people of knowledge. Al-Awza'i said: "Whoever meets up with the Muslims before the horses, share is distributed, then he is given a share." And Buraid's (a narrator) Kunyah is Abu Buraidah and he is trustworthy. Sufyan Ath-Thawri, Ibn 'Uyainah and others report from him}}
\hadithdefcmd{tirmidhi}{1560}{\hadithno{1560}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1561}{\hadithno{1561}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1561p2}{\hadithno{1561.2}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1562}{\hadithno{1562}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1563}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ جَهْضَمِ بْنِ عَبْدِ اللَّهِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ مُحَمَّدِ بْنِ زَيْدٍ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ شِرَاءِ الْمَغَانِمِ حَتَّى تُقْسَمَ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{1563}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Sa’id Al Khudri : "The Messenger of Allah (ﷺ) prohibited selling the spoils of war until it has been distributed." There is something on this topic from Abu Hurairah. [Abu 'Eisa said:] This Hadith is Gharib}}
\hadithdefcmd{tirmidhi}{1564}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى النَّيْسَابُورِيُّ، حَدَّثَنَا أَبُو عَاصِمٍ النَّبِيلُ، عَنْ وَهْبٍ أَبِي خَالِدٍ، قَالَ حَدَّثَتْنِي أُمُّ حَبِيبَةَ بِنْتُ عِرْبَاضِ بْنِ سَارِيَةَ، أَنَّ أَبَاهَا، أَخْبَرَهَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ تُوطَأَ السَّبَايَا حَتَّى يَضَعْنَ مَا فِي بُطُونِهِنَّ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ رُوَيْفِعِ بْنِ ثَابِتٍ ‏.‏ وَحَدِيثُ عِرْبَاضٍ حَدِيثٌ غَرِيبٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ وَقَالَ الأَوْزَاعِيُّ إِذَا اشْتَرَى الرَّجُلُ الْجَارِيَةَ مِنَ السَّبْىِ وَهِيَ حَامِلٌ فَقَدْ رُوِيَ عَنْ عُمَرَ بْنِ الْخَطَّابِ أَنَّهُ قَالَ لاَ تُوطَأُ حَامِلٌ حَتَّى تَضَعَ ‏.‏ قَالَ الأَوْزَاعِيُّ وَأَمَّا الْحَرَائِرُ فَقَدْ مَضَتِ السُّنَّةُ فِيهِنَّ بِأَنْ أُمِرْنَ بِالْعِدَّةِ ‏.‏ قَالَ حَدَّثَنِي بِذَلِكَ عَلِيُّ بْنُ خَشْرَمٍ قَالَ حَدَّثَنَا عِيسَى بْنُ يُونُسَ عَنِ الأَوْزَاعِيِّ ‏.‏\hadithno{1564}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Umm Habibah bint 'Irbad bin Sariyah: From her father who told her that the Messenger of Allah (ﷺ) prohibited intercourse with female prisoners, until they deliver what is in their wombs." [Abu 'Eisa said:] There is something on this topic from Ruwaifi' bin Thabit, and the Hadith of 'Irbad is a Gharib Hadith. This is acted upon according to the people of knowledge. Al-Awza'i said: "When a man purchases a slave girl from the captives and she is pregnant, then it has been related from 'Umar bin Al-Khattab that he said: 'Do not have intercourse with the pregnant women until she gives birth.'" Al-Awza'i said: "As for the free women, then the Sunnah about them has passed, in that the 'Iddah is observed." All of this was narrated to me by 'Ali bin Khushram who said: " 'Eisa bin Yunus narrated to us from Al-Awza'i}}
\hadithdefcmd{tirmidhi}{1565}{\hadithno{1565}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1566}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ الشَّيْبَانِيُّ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي حُيَىٌّ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنْ أَبِي أَيُّوبَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ فَرَّقَ بَيْنَ وَالِدَةٍ وَوَلَدِهَا فَرَّقَ اللَّهُ بَيْنَهُ وَبَيْنَ أَحِبَّتِهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَلِيٍّ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ كَرِهُوا التَّفْرِيقَ بَيْنَ السَّبْىِ بَيْنَ الْوَالِدَةِ وَوَلَدِهَا وَبَيْنَ الْوَلَدِ وَالْوَالِدِ وَبَيْنَ الإِخْوَةِ ‏.‏ قَالَ أَبُو عِيسَى وَسَمِعْتُ الْبُخَارِيَّ يَقُولُ سَمِعَ أَبُو عَبْدِ الرَّحْمَنِ الْحُبُلِيُّ مِنْ أَبِي أَيُّوبَ ‏.‏\hadithno{1566}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Ayyub: That he heard the Messenger of Allah (ﷺ) say: "Whoever separates between a mother and her child, then Allah will separate between him and his beloved on the Day of Judgement." [Abu 'Eisa said:] There is something on this topic from 'Ali. This Hadith is Hasan Gharib. This is acted upon according to the people of knowledge among the Companions of the Prophet (ﷺ) and others. They dislike separating the captives, the mother and her child, the son and the father, and brothers}}
\hadithdefcmd{tirmidhi}{1567}{حَدَّثَنَا أَبُو عُبَيْدَةَ بْنُ أَبِي السَّفَرِ، - وَاسْمُهُ أَحْمَدُ بْنُ عَبْدِ اللَّهِ الْهَمْدَانِيُّ وَمَحْمُودُ بْنُ غَيْلاَنَ قَالاَ حَدَّثَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنْ سُفْيَانَ بْنِ سَعِيدٍ، عَنْ هِشَامٍ، عَنِ ابْنِ سِيرِينَ، عَنْ عَبِيدَةَ، عَنْ عَلِيٍّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ جِبْرَائِيلَ هَبَطَ عَلَيْهِ فَقَالَ لَهُ خَيِّرْهُمْ يَعْنِي أَصْحَابَكَ فِي أُسَارَى بَدْرٍ الْقَتْلَ أَوِ الْفِدَاءَ عَلَى أَنْ يُقْتَلَ مِنْهُمْ قَابِلاً مِثْلُهُمْ ‏.‏ قَالُوا الْفِدَاءَ وَيُقْتَلَ مِنَّا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَأَنَسٍ وَأَبِي بَرْزَةَ وَجُبَيْرِ بْنِ مُطْعِمٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ الثَّوْرِيِّ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ ابْنِ أَبِي زَائِدَةَ ‏.‏ وَرَوَى أَبُو أُسَامَةَ عَنْ هِشَامٍ عَنِ ابْنِ سِيرِينَ عَنْ عَبِيدَةَ عَنْ عَلِيٍّ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ وَرَوَى ابْنُ عَوْنٍ عَنِ ابْنِ سِيرِينَ عَنْ عَبِيدَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏ وَأَبُو دَاوُدَ الْحَفَرِيُّ اسْمُهُ عُمَرُ بْنُ سَعْدٍ ‏.‏\hadithno{1567}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Ali: That the Messenger of Allah (ﷺ) said that Jibra'il had indeed descended upon him to say to him: "Tell them - meaning your Companions - to choose regarding the captives of Badr, between either killing them or ransoming the, so that the amount killed by them will correspond similarly to them." So they said: "Ranson, even though some of us may be killed." There are narrations on this topic from Ibn Mas'ud, Anas, Abu Barzah, and Jubair bin Mut'im. [Abu 'Eisa said:] This Hadith is Hasan Gharib as a narration of Ath-Thawri. We do not know of it except through the report of Za'idah. Abu Usamah reported similar to this from Hisham, from Ibn Sirin, from 'Abidah, from 'Ali, from the Prophet (ﷺ) Ibn 'Awn reported it from Ibn Sirin, from 'Abidah, from 'Ali, from the Prophet (ﷺ) in Mursal form. Abu Dawud Al-Hafiri's ( a narrator in this chain) name is 'Umar bin Sa'd}}
\hadithdefcmd{tirmidhi}{1568}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، عَنْ عَمِّهِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم فَدَى رَجُلَيْنِ مِنَ الْمُسْلِمِينَ بِرَجُلٍ مِنَ الْمُشْرِكِينَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَعَمُّ أَبِي قِلاَبَةَ هُوَ أَبُو الْمُهَلَّبِ وَاسْمُهُ عَبْدُ الرَّحْمَنِ بْنُ عَمْرٍو وَيُقَالُ مُعَاوِيَةُ بْنُ عَمْرٍو وَأَبُو قِلاَبَةَ اسْمُهُ عَبْدُ اللَّهِ بْنُ زَيْدٍ الْجَرْمِيُّ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّ لِلإِمَامِ أَنْ يَمُنَّ عَلَى مَنْ شَاءَ مِنَ الأُسَارَى وَيَقْتُلَ مَنْ شَاءَ مِنْهُمْ وَيَفْدِيَ مَنْ شَاءَ ‏.‏ وَاخْتَارَ بَعْضُ أَهْلِ الْعِلْمِ الْقَتْلَ عَلَى الْفِدَاءِ ‏.‏ وَقَالَ الأَوْزَاعِيُّ بَلَغَنِي أَنَّ هَذِهِ الآيَةَ مَنْسُوخَةٌ قَوْلُهُ تَعَالَى‏:‏ ‏(‏فَإِِمَّا مَنًّا بَعْدُ وَإِمَّا فِدَاءً‏)‏ نَسَخَتْهَا‏:‏ ‏(‏وَاقْتُلُوهُمْ حَيْثُ ثَقِفْتُمُوهُمْ ‏)‏ حَدَّثَنَا بِذَلِكَ هَنَّادٌ حَدَّثَنَا ابْنُ الْمُبَارَكِ عَنِ الأَوْزَاعِيِّ ‏.‏ قَالَ إِسْحَاقُ بْنُ مَنْصُورٍ قُلْتُ لأَحْمَدَ إِذَا أُسِرَ الأَسِيرُ يُقْتَلُ أَوْ يُفَادَى أَحَبُّ إِلَيْكَ قَالَ إِنْ قَدَرُوا أَنْ يُفَادُوا فَلَيْسَ بِهِ بَأْسٌ وَإِنْ قُتِلَ فَمَا أَعْلَمُ بِهِ بَأْسًا ‏.‏ قَالَ إِسْحَاقُ بْنُ إِبْرَاهِيمَ الإِثْخَانُ أَحَبُّ إِلَىَّ إِلاَّ أَنْ يَكُونَ مَعْرُوفًا فَأَطْمَعُ بِهِ الْكَثِيرَ ‏.‏\hadithno{1568}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Imran bin Husain: That the Prophet (ﷺ) ransomed two men for the Muslims with a man from the idolaters. [Abu 'Eisa said:] This Hadith is Hasan Sahih. The paternal uncle of Abu Al-Muhallab's name is 'Abdur Rahman bin 'Amr, and they also say it was Muhawiyah bin 'Amr. And Abu Qilabah's name is 'Abdullah bin Zaid Al-Jarmi (narrator in the chain) This is acted upon according to most of the people of knowledge among the Companions of the Prophet(ﷺ) and others. It is for the Imam to decide to be generous with whom he wills among the captives, or to kill whom he wills among them, or to ransom whom he wills among them. Some of the people of knowledge preferred killing over ransoming. Al-Awzai' said: "It has been conveyed to me. that this Ayah is abrogated: Thereafter (is the time) either for generosity (to free them without ranson) or ransom (47:4). It was abrogated by: Kill them wherever you find them (2:191). This was narrated to us by Hannad (who said): "Ibn Al-Mubarak narrated to us, from Al-Awza'i." Ishaq bin Mansur said: "I said to Ahmad: 'When the captives are captured' is killing or ransoming better to you?' He said: 'If they are able to ransom' then there is no harm in it. And if they kill, then I do not know of any harm in it.'" Ishaq said: "Wiping them out is better to me, unless it is someone well-known, so that it is hoped that a large amount will be obtained for him}}
\hadithdefcmd{tirmidhi}{1569}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَخْبَرَهُ أَنَّ امْرَأَةً وُجِدَتْ فِي بَعْضِ مَغَازِي رَسُولِ اللَّهِ صلى الله عليه وسلم مَقْتُولَةً فَأَنْكَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَلِكَ وَنَهَى عَنْ قَتْلِ النِّسَاءِ وَالصِّبْيَانِ ‏.‏ وَفِي الْبَابِ عَنْ بُرَيْدَةَ وَرَبَاحٍ وَيُقَالُ رِيَاحُ بْنُ الرَّبِيعِ وَالأَسْوَدِ بْنِ سَرِيعٍ وَابْنِ عَبَّاسٍ وَالصَّعْبِ بْنِ جَثَّامَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ كَرِهُوا قَتْلَ النِّسَاءِ وَالْوِلْدَانِ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَالشَّافِعِيِّ ‏.‏ وَرَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ فِي الْبَيَاتِ وَقَتْلِ النِّسَاءِ فِيهِمْ وَالْوِلْدَانِ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ وَرَخَّصَا فِي الْبَيَاتِ ‏.‏\hadithno{1569}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Umar: That a woman was found killed in one of the expeditions of the Messenger of Allah (ﷺ), so the Messenger of Allah (ﷺ) rebuked that, and he prohibited killing women and children. There are narrations on this topic from Buraidah and Rabah - and they say he was Riyah - bin Ar-Rabi', Al-Aswad bin Sari', Ibn 'Abbas, and As-Sa'b bin Jaththamah. [Abu 'Eisa said:] This Hadith is Hasan Sahih. This is acted upon according to some of the people of knowledge among the Companions of the Prophet (ﷺ) and others. They disliked killing women and children. This is the view of Sufyan Ath-Thawri and Ash-Shafi'i. Some of the people of knowledge made an exception for killing the women who had children with them during night attacks, this is the view of Ahmad and Ishaq, they permitted it in night attacks}}
\hadithdefcmd{tirmidhi}{1570}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَخْبَرَنِي الصَّعْبُ بْنُ جَثَّامَةَ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ خَيْلَنَا أَوْطَأَتْ مِنْ نِسَاءِ الْمُشْرِكِينَ وَأَوْلاَدِهِمْ ‏.‏ قَالَ ‏ "‏ هُمْ مِنْ آبَائِهِمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1570}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Abbas: "I was informed by As-Sa'b bin Jaththamah who said: " I said: "O Messenger of Allah our horses trampled over women and children of the idolaters." He said: "They are from their fathers.'" [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1571}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ بَعَثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَعْثٍ فَقَالَ ‏"‏ إِنْ وَجَدْتُمْ فُلاَنًا وَفُلاَنًا لِرَجُلَيْنِ مِنْ قُرَيْشٍ فَأَحْرِقُوهُمَا بِالنَّارِ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ أَرَدْنَا الْخُرُوجَ ‏"‏ إِنِّي كُنْتُ أَمَرْتُكُمْ أَنْ تَحْرِقُوا فُلاَنًا وَفُلاَنًا بِالنَّارِ وَإِنَّ النَّارَ لاَ يُعَذِّبُ بِهَا إِلاَّ اللَّهُ فَإِنْ وَجَدْتُمُوهُمَا فَاقْتُلُوهُمَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَحَمْزَةَ بْنِ عَمْرٍو الأَسْلَمِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏ وَقَدْ ذَكَرَ مُحَمَّدُ بْنُ إِسْحَاقَ بَيْنَ سُلَيْمَانَ بْنِ يَسَارٍ وَبَيْنَ أَبِي هُرَيْرَةَ رَجُلاً فِي هَذَا الْحَدِيثِ وَرَوَى غَيْرُ وَاحِدٍ مِثْلَ رِوَايَةِ اللَّيْثِ وَحَدِيثُ اللَّيْثِ بْنِ سَعْدٍ أَشْبَهُ وَأَصَحُّ ‏.‏ قَالَ الْبُخَارِيُّ وَسُلَيْمَانُ بْنُ يَسَارٍ قَدْ سَمِعَ مِنْ أَبِي هُرَيْرَةَ ‏.‏ قَالَ مُحَمَّدٌ وَحَدِيثُ حَمْزَةَ بْنِ عَمْرٍو فِي هَذَا الْبَابِ صَحِيحٌ ‏.‏\hadithno{1571}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Abu Hurairah: "The Messenger of Allah (ﷺ) sent us with an army and said: 'If you see so-and-so, and so-and-so' referring to two men from the Quraish: 'then burn them with fire.' Then, upon our departure, the Messenger of Allah (ﷺ) said: 'I ordered you to burn so-and-so, and so-and-so with fire, and indeed, none punishes with fire except Allah. So if you see them, then kill them.'" There are narrations on this topic from Ibn 'Abbas and Hamzah bin 'Amr Al-Aslami. [Abu 'Eisa said:] The Hadith of Abu Hurairah is a Hasan Sahih Hadith. This is acted upon according to the people of knowledge. In this Hadith, Muhammad bin Ishaq mentioned a man (narrating) between Sulaiman bin Yasar and Abu Hurairah. Others reported this Hadith the same as Al-Laith reported it(here, without a man between them). The narration of Al-Laith bin Sa'd is more appropriate and more correct}}
\hadithdefcmd{tirmidhi}{1572}{حَدَّثَنِي أَبُو رَجَاءٍ، قُتَيْبَةُ بْنُ سَعِيدٍ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ ثَوْبَانَ، قَالَ قَالَ رَسُولُ اللَّهِ ‏ "‏ مَنْ مَاتَ وَهُوَ بَرِيءٌ مِنْ ثَلاَثٍ الْكِبْرِ وَالْغُلُولِ وَالدَّيْنِ دَخَلَ الْجَنَّةَ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَزَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ ‏.‏\hadithno{1572}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Thawban: That the Messenger of Allah (ﷺ) said: "Whoever dies and he is free of three: Kibr (Pride), Ghulul, and debt, he will enter paradise." There are narrations on this topic from Abu Hurairah and Zaid bin Khalid Al-Juhni Footnote: Ghulul refers to goods stolen from the spoils of war, or concealed, before it is divided among the soldiers}}
\hadithdefcmd{tirmidhi}{1573}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ مَعْدَانَ بْنِ أَبِي طَلْحَةَ، عَنْ ثَوْبَانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ فَارَقَ الرُّوحُ الْجَسَدَ وَهُوَ بَرِيءٌ مِنْ ثَلاَثٍ الْكَنْزِ وَالْغُلُولِ وَالدَّيْنِ دَخَلَ الْجَنَّةَ ‏"‏ ‏.‏ هَكَذَا قَالَ سَعِيدٌ الْكَنْزَ وَقَالَ أَبُو عَوَانَةَ فِي حَدِيثِهِ الْكِبْرَ وَلَمْ يَذْكُرْ فِيهِ عَنْ مَعْدَانَ وَرِوَايَةُ سَعِيدٍ أَصَحُّ ‏.‏\hadithno{1573}\hadithgrade{Ahmad Muhammad Shakir: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Daif}\hadithtrans{Narrated Thawban:That the Messenger of Allah (ﷺ) said: "Whoever's soul departs from his body while he is free of three: Kanz (buried treasure), Ghulul, and debt, then he will enter paradise." This is how Sa'eed narrated it: "Kanz" while Abu 'Awanah said in his narration: "Kibr" and he did not mention "from Ma'dan" in it. But the narration of Sa'eed is more correct}}
\hadithdefcmd{tirmidhi}{1574}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، حَدَّثَنَا سِمَاكٌ أَبُو زُمَيْلٍ الْحَنَفِيُّ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ حَدَّثَنِي عُمَرُ بْنُ الْخَطَّابِ، قَالَ قِيلَ يَا رَسُولَ اللَّهِ إِنَّ فُلاَنًا قَدِ اسْتُشْهِدَ ‏.‏ قَالَ ‏ "‏ كَلاَّ قَدْ رَأَيْتُهُ فِي النَّارِ بِعَبَاءَةٍ قَدْ غَلَّهَا قَالَ قُمْ يَا عَلِيُّ فَنَادِ إِنَّهُ لاَ يَدْخُلُ الْجَنَّةَ إِلاَّ الْمُؤْمِنُونَ ثَلاَثًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{1574}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Simak Abu Rumail Al-Hanafi: "I heard Ibn 'Abbas saying: 'Umar bin Al-Khattab narrated to me that he said: "It was said: 'O Messenger of Allah! So-and-so has been martyred.' He said: "No! I saw him in the fire of garment he pilfered from the spoils of war.' He said: 'Stand up O 'Umar! Call out that no one enters paradise except the believers.' Three times." [Abu 'Eisa said:] This Hadith is Hasan Sahih Gharib}}
\hadithdefcmd{tirmidhi}{1575}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الصَّوَّافُ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ الضُّبَعِيُّ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَغْزُو بِأُمِّ سُلَيْمٍ وَنِسْوَةٍ مَعَهَا مِنَ الأَنْصَارِ يَسْقِينَ الْمَاءَ وَيُدَاوِينَ الْجَرْحَى ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ الرُّبَيِّعِ بِنْتِ مُعَوِّذٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1575}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Anas: "The Messenger of Allah (ﷺ) used to go to battle with Umm Sulaim, and other women with her, from the Ansar, who would give water and attend to the wounded." [Abu 'Eisa said:] There is something on this topic from Ar-Rabi' bin Mu'awwidh. This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1576}{حَدَّثَنَا عَلِيُّ بْنُ سَعِيدٍ الْكِنْدِيُّ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ إِسْرَائِيلَ، عَنْ ثُوَيْرٍ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّ كِسْرَى أَهْدَى إِلَيْهِ فَقَبِلَ مِنْهُ وَأَنَّ الْمُلُوكَ أَهْدَوْا إِلَيْهِ فَقَبِلَ مِنْهُمْ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَثُوَيْرٌ هُوَ ابْنُ أَبِي فَاخِتَةَ وَأَبُو فَاخِتَةَ اسْمُهُ سَعِيدُ بْنُ عِلاَقَةَ وَثُوَيْرٌ يُكْنَى أَبَا جَهْمٍ ‏.‏\hadithno{1576}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Ali: From the Prophet (ﷺ), that Kisra sent him a gift so he accepted, and that kings gave him gifts and he accepted them. There is something about this from Jabir. This is a Hasan Gharib Hadith. Thuwair (a narrator in the chain) is Ibn Abi Fakhitah, whose name was Sa'eed bin 'Illaqah, and Thuwair's Kunyah was Abu Jahm}}
\hadithdefcmd{tirmidhi}{1577}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ، عَنْ عِمْرَانَ الْقَطَّانِ، عَنْ قَتَادَةَ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ، هُوَ ابْنُ الشِّخِّيرِ عَنْ عِيَاضِ بْنِ حِمَارٍ، أَنَّهُ أَهْدَى لِلنَّبِيِّ صلى الله عليه وسلم هَدِيَّةً لَهُ أَوْ نَاقَةً فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَسْلَمْتَ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَإِنِّي نُهِيتُ عَنْ زَبْدِ الْمُشْرِكِينَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَمَعْنَى قَوْلِهِ ‏"‏ إِنِّي نُهِيتُ عَنْ زَبْدِ الْمُشْرِكِينَ ‏"‏ ‏.‏ يَعْنِي هَدَايَاهُمْ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَقْبَلُ مِنَ الْمُشْرِكِينَ هَدَايَاهُمْ وَذُكِرَ فِي هَذَا الْحَدِيثِ الْكَرَاهِيَةُ وَاحْتُمِلَ أَنْ يَكُونَ هَذَا بَعْدَ مَا كَانَ يَقْبَلُ مِنْهُمْ ثُمَّ نَهَى عَنْ هَدَايَاهُمْ ‏.‏\hadithno{1577}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Iyad bin Himar: That he gave the Prophet (ﷺ) a gift or a camel, so the Prophet (ﷺ) said: "Have you accepted Islam?" He said: "No." He said: "Then I have been prohibited from the Zabd (gift) of the idolaters." [Abu 'Eisa said:] This Hadith is Hasan Sahih. And the meaning of his saying: "I haven been prohibited from the Zabd (gifts) of the idolaters" is their gifts. It has been reported about the Messenger (ﷺ) that he used to accept the gifts of the idolaters while a dislike for that is mentioned in this Hadith. And the implication is that this was after he used to accept from them, and then he later forbade their gifts}}
\hadithdefcmd{tirmidhi}{1578}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا بَكَّارُ بْنُ عَبْدِ الْعَزِيزِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، عَنْ أَبِي بَكْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَتَاهُ أَمْرٌ فَسُرَّ بِهِ فَخَرَّ لِلَّهِ سَاجِدًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ بَكَّارِ بْنِ عَبْدِ الْعَزِيزِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ رَأَوْا سَجْدَةَ الشُّكْرِ ‏.‏ وَبَكَّارُ بْنُ عَبْدِ الْعَزِيزِ بْنِ أَبِي بَكْرَةَ مُقَارِبُ الْحَدِيثِ ‏.‏\hadithno{1578}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Bakrah: "The Prophet (ﷺ) was met by some affair that made him happy, so he prostrated to Allah." [Abu 'Eisa said:] This Hadith is Hasan Gharib, we do not know of it except from this route, as a narration of Bakkar bin 'Abdul-'Aziz. This is acted upon according to most of the people of knowledge, they held the view that one could perform the prostration of gratitude. And Bakkar bin 'Adbul-'Aziz bin Abi Bakrah is Muqarib (average) in Hadith}}
\hadithdefcmd{tirmidhi}{1579}{\hadithno{1579}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1580}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَنْبَأَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي أَبُو الْفَيْضِ، قَالَ سَمِعْتُ سُلَيْمَ بْنَ عَامِرٍ، يَقُولُ كَانَ بَيْنَ مُعَاوِيَةَ وَبَيْنَ أَهْلِ الرُّومِ عَهْدٌ وَكَانَ يَسِيرُ فِي بِلاَدِهِمْ حَتَّى إِذَا انْقَضَى الْعَهْدُ أَغَارَ عَلَيْهِمْ فَإِذَا رَجُلٌ عَلَى دَابَّةٍ أَوْ عَلَى فَرَسٍ وَهُوَ يَقُولُ اللَّهُ أَكْبَرُ وَفَاءٌ لاَ غَدْرٌ ‏.‏ وَإِذَا هُوَ عَمْرُو بْنُ عَبَسَةَ فَسَأَلَهُ مُعَاوِيَةُ عَنْ ذَلِكَ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ كَانَ بَيْنَهُ وَبَيْنَ قَوْمٍ عَهْدٌ فَلاَ يَحُلَّنَّ عَهْدًا وَلاَ يَشُدَّنَّهُ حَتَّى يَمْضِيَ أَمَدُهُ أَوْ يَنْبِذَ إِلَيْهِمْ عَلَى سَوَاءٍ ‏"‏ ‏.‏ قَالَ فَرَجَعَ مُعَاوِيَةُ بِالنَّاسِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1580}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Al-Faid: "I heard Sulaim bin 'Amir saying: 'There was a treaty between Mu'awiyah and the people of Rome. He was making an expedition into their lands so that when the period of the treaty was expires he would attack them. So when a man upon an animal' - or - 'upon a horse said: "Allahu Akbar! Fulfillment not betrayal!" - and it turned out to be 'Amr bin 'Abasah - Mu'awiyah asked him about that. He said: "I heard the Messenger of Allah (ﷺ) said: 'Whoever has a treaty between himself and a people, then let him not violate the treaty nor try to change it until its time has passed, or , in retribution for a similar offense.'" He said: "So Mu'awiyah returned with the people." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1581}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنِي صَخْرُ بْنُ جُوَيْرِيَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ الْغَادِرَ يُنْصَبُ لَهُ لِوَاءٌ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَعَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَأَبِي سَعِيدٍ الْخُدْرِيِّ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَسَأَلْتُ مُحَمَّدًا عَنْ حَدِيثِ سُوَيْدٍ عَنْ أَبِي إِسْحَاقَ عَنْ عُمَارَةَ بْنِ عُمَيْرٍ عَنْ عَلِيٍّ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لِكُلِّ غَادِرٍ لِوَاءٌ ‏"‏ ‏.‏ فَقَالَ لاَ أَعْرِفُ هَذَا الْحَدِيثَ مَرْفُوعًا ‏.‏\hadithno{1581}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Umar: The Messenger of Allah (ﷺ) said: "Indeed the one who betrays will have a banner erected for him on the Day of Judgement." [He said:] There are narrations on this topic from 'Ali, 'Abdullah bin Mas'ud, Abu Sa'eed Al-Khudri, and Anas. [Abu 'Eisa said:] This Hadith is Hasan Sahih. I asked Muhammad about the Hadith of Suwaid, from Abu Ishaq, from 'Umarah bin 'Umair, from 'Ali, from the Prophet (ﷺ) who said: "For every person who betrays there will be banner." He said: "I do not know of this Hadith being Marfu}}
\hadithdefcmd{tirmidhi}{1582}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّهُ قَالَ رُمِيَ يَوْمَ الأَحْزَابِ سَعْدُ بْنُ مُعَاذٍ فَقَطَعُوا أَكْحَلَهُ أَوْ أَبْجَلَهُ فَحَسَمَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالنَّارِ فَانْتَفَخَتْ يَدُهُ فَتَرَكَهُ فَنَزَفَهُ الدَّمُ فَحَسَمَهُ أُخْرَى فَانْتَفَخَتْ يَدُهُ فَلَمَّا رَأَى ذَلِكَ قَالَ اللَّهُمَّ لاَ تُخْرِجْ نَفْسِي حَتَّى تُقِرَّ عَيْنِي مِنْ بَنِي قُرَيْظَةَ ‏.‏ فَاسْتَمْسَكَ عِرْقُهُ فَمَا قَطَرَ قَطْرَةً حَتَّى نَزَلُوا عَلَى حُكْمِ سَعْدِ بْنِ مُعَاذٍ فَأَرْسَلَ إِلَيْهِ فَحَكَمَ أَنْ يُقْتَلَ رِجَالُهُمْ وَيُسْتَحْيَى نِسَاؤُهُمْ يَسْتَعِينُ بِهِنَّ الْمُسْلِمُونَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَصَبْتَ حُكْمَ اللَّهِ فِيهِمْ ‏"‏ ‏.‏ وَكَانُوا أَرْبَعَمِائَةٍ فَلَمَّا فَرَغَ مِنْ قَتْلِهِمُ انْفَتَقَ عِرْقُهُ فَمَاتَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَعَطِيَّةَ الْقُرَظِيِّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1582}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir:"On the day of (the battle of) Al-Ahzab, Sa'd bin Mu'adh was struck by an arrow such that the upper vein or lower vein of his forearm was severed. So the Messenger of Allah (ﷺ) tried to stop it with fire, but it made his arm bleed profusely so he left it. Then he did it another time but it caused it to bleed profusely. Upon seeing that he said: 'O Allah! Do not allow my soul depart until my eyes are comforted by elimination of Banu Quraizah.' He pressed his vein closed and it did not bleed a drop before they surrendered to the arbitration of Sa'd bin Mu'adh. He (the Prophet (ﷺ)) sent to him (Sa'd) who judged that their men should be killed, their women should be spared, and that the Muslims may share them among themselves. With this, the Messenger of Allah (ﷺ) said: 'You have judged according to Allah's judgement for them.' And they were four hundred. Then when he finished killing them, his vein opened up and he died." [He said:] There are narrations on this topic from Abu Sa'eed and 'Atiyyah Al-Qurazi. [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1583}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ الرَّحْمَنِ أَبُو الْوَلِيدِ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنْ سَعِيدِ بْنِ بَشِيرٍ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اقْتُلُوا شُيُوخَ الْمُشْرِكِينَ وَاسْتَحْيُوا شَرْخَهُمْ ‏"‏ ‏.‏ وَالشَّرْخُ الْغِلْمَانُ الَّذِينَ لَمْ يُنْبِتُوا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَرَوَاهُ الْحَجَّاجُ بْنُ أَرْطَاةَ عَنْ قَتَادَةَ نَحْوَهُ ‏.‏\hadithno{1583}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Samurah bin Jundab: That the Messenger of Allah (ﷺ) said: "Kill the elder men among the idolaters and spare the Sharkh amont them." And the Sharkh are the boys who did not begin to grow pubic hair. [Abu 'Eisa said:] This Hadith is Hasan Sahih. Hajjaj bin Artah narrated similarly from Qatadah}}
\hadithdefcmd{tirmidhi}{1584}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ عَطِيَّةَ الْقُرَظِيِّ، قَالَ عُرِضْنَا عَلَى النَّبِيِّ صلى الله عليه وسلم يَوْمَ قُرَيْظَةَ فَكَانَ مَنْ أَنْبَتَ قُتِلَ وَمَنْ لَمْ يُنْبِتْ خُلِّيَ سَبِيلُهُ فَكُنْتُ مِمَّنْ لَمْ يُنْبِتْ فَخُلِّيَ سَبِيلِي ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ أَنَّهُمْ يَرَوْنَ الإِنْبَاتَ بُلُوغًا إِنْ لَمْ يُعْرَفِ احْتِلاَمُهُ وَلاَ سِنُّهُ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1584}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Atiyyah Al-Qurazi: "We were presented to the Messenger of Allah (ﷺ) on the day of (the battle of) Quraizah. Whoever had pubic hair was killed and whoever did not was left to his way. I was of those who did not have pubic hair so I was left to my way." [Abu 'Eisa said:] This Hadith is Hasan Sahih. This is acted upon according to some of the people of knowledge. They consider pubic hair an indication of the age of responsibility, if it is not known whether he has had a wet dream, or his age. This is the view of Ahmad and Ishaq}}
\hadithdefcmd{tirmidhi}{1585}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ فِي خُطْبَتِهِ ‏ "‏ أَوْفُوا بِحِلْفِ الْجَاهِلِيَّةِ فَإِنَّهُ لاَ يَزِيدُهُ يَعْنِي الإِسْلاَمَ إِلاَّ شِدَّةً وَلاَ تُحْدِثُوا حِلْفًا فِي الإِسْلاَمِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَأُمِّ سَلَمَةَ وَجُبَيْرِ بْنِ مُطْعِمٍ وَأَبِي هُرَيْرَةَ وَابْنِ عَبَّاسٍ وَقَيْسِ بْنِ عَاصِمٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1585}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amr bin Shu'aib: From his father, from his grandfather, that the Messenger of Allah (ﷺ) said during his Khutbah: "Fulfill the allegiances sworn in Jahiliyyah for it" - meaning Islam - "does not add to them except in gravity. And do not initiate new allegiances in Islam." [He said:] There are narration on this topic from 'Abdur-Rahman bin 'Awf, Umm Salamah, Jubair bin Mut'im, Abu Hurairah, Ibn 'Abbas, and Qais bin 'Asim. [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1586}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الْحَجَّاجُ بْنُ أَرْطَاةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ بَجَالَةَ بْنِ عَبْدَةَ، قَالَ كُنْتُ كَاتِبًا لِجَزْءِ بْنِ مُعَاوِيَةَ عَلَى مَنَاذِرَ فَجَاءَنَا كِتَابُ عُمَرَ انْظُرْ مَجُوسَ مَنْ قِبَلَكَ فَخُذْ مِنْهُمُ الْجِزْيَةَ فَإِنَّ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ أَخْبَرَنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَخَذَ الْجِزْيَةَ مِنْ مَجُوسِ هَجَرَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{1586}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Bajalah bin 'Abdah : "I was a scribe for Jaz' bin Mu'awiyah at Manadhir when 'Umar's letter came to us (saying): 'Inspect the Zoroastrians around you to take the Jizyah from them. For indeed 'Abdur-Rahman bin 'Awf informed me that the Messenger of Allah (ﷺ) took the Jizyah from the Zoroastrians of Hajar.'" [Abu 'Eisa said:] This Hadith is Hasan}}
\hadithdefcmd{tirmidhi}{1587}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ بَجَالَةَ، أَنَّ عُمَرَ، كَانَ لاَ يَأْخُذُ الْجِزْيَةَ مِنَ الْمَجُوسِ حَتَّى أَخْبَرَهُ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَخَذَ الْجِزْيَةَ مِنْ مَجُوسِ هَجَرَ ‏.‏ وَفِي الْحَدِيثِ كَلاَمٌ أَكْثَرُ مِنْ هَذَا ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1587}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Bajalah: That 'Umar would not take the Jizyah from the Zoroastrians until 'Abdur-Rahman bin 'Awf informed him that the Prophet (ﷺ) took Jizyah from the Zoroastrians of Hajar." There is more dialogue in the Hadith than this. And this Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1588}{حَدَّثَنَا الْحُسَيْنُ بْنُ أَبِي كَبْشَةَ الْبَصْرِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مَالِكٍ، عَنِ الزُّهْرِيِّ، عَنِ السَّائِبِ بْنِ يَزِيدَ، قَالَ أَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْجِزْيَةَ مِنْ مَجُوسِ الْبَحْرَيْنِ وَأَخَذَهَا عُمَرُ مِنْ فَارِسَ وَأَخَذَهَا عُثْمَانُ مِنَ الْفُرْسِ ‏.‏ وَسَأَلْتُ مُحَمَّدًا عَنْ هَذَا فَقَالَ هُوَ مَالِكٌ عَنِ الزُّهْرِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1588}\hadithgrade{Zubair Ali Zai: Hasan}\hadithtrans{Narrated Malik :From Az-Zuhri, that Sa'ib bin Yazid said: "The Messenger of Allah (ﷺ) took the Jizyah from the Zoroastrians of Bahrain, and 'Umar took it in Persia, and 'Uthman took it from the Persians." I asked Muhammad about this, so he said: "It is: 'Malik from Az-Zuhri from the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{1589}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّا نَمُرُّ بِقَوْمٍ فَلاَ هُمْ يُضَيِّفُونَا وَلاَ هُمْ يُؤَدُّونَ مَا لَنَا عَلَيْهِمْ مِنَ الْحَقِّ وَلاَ نَحْنُ نَأْخُذُ مِنْهُمْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنْ أَبَوْا إِلاَّ أَنْ تَأْخُذُوا كَرْهًا فَخُذُوا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رَوَاهُ اللَّيْثُ بْنُ سَعْدٍ عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ أَيْضًا ‏.‏ وَإِنَّمَا مَعْنَى هَذَا الْحَدِيثِ أَنَّهُمْ كَانُوا يَخْرُجُونَ فِي الْغَزْوِ فَيَمُرُّونَ بِقَوْمٍ وَلاَ يَجِدُونَ مِنَ الطَّعَامِ مَا يَشْتَرُونَ بِالثَّمَنِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنْ أَبَوْا أَنْ يَبِيعُوا إِلاَّ أَنْ تَأْخُذُوا كَرْهًا فَخُذُوا ‏"‏ ‏.‏ هَكَذَا رُوِيَ فِي بَعْضِ الْحَدِيثِ مُفَسَّرًا وَقَدْ رُوِيَ عَنْ عُمَرَ بْنِ الْخَطَّابِ رضى الله عنه أَنَّهُ كَانَ يَأْمُرُ بِنَحْوِ هَذَا ‏.‏\hadithno{1589}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Uqbah bin 'Amir: "I said: 'O Messenger of Allah! We come across a people and they do not host us, and they do not give us our rights, and we do not take anything from them. So the Messenger of Allah (ﷺ) said: 'If they refuse such that you can only take by force, then take.'" [Abu 'Eisa said:] This Hadith is Hasan. It has been reported by Al-Laith bin Sa'd from Yazid bin Abi Habib as well. This Hadith only means that they would go out for battles and they would pass a people among whom they would not find any food to buy for a price. So the Prophet (ﷺ) told them: If they refuse to sell you, such that you have to take it forcefully, then take it. This is how the explanation has been related in some of the Ahadith. And it has been related that 'Umar bin Al-Khattab, may Allah be please with him, would order similarly}}
\hadithdefcmd{tirmidhi}{1590}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، حَدَّثَنَا زِيَادُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مَنْصُورُ بْنُ الْمُعْتَمِرِ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ فَتْحِ مَكَّةَ ‏ "‏ لاَ هِجْرَةَ بَعْدَ الْفَتْحِ وَلَكِنْ جِهَادٌ وَنِيَّةٌ وَإِذَا اسْتُنْفِرْتُمْ فَانْفِرُوا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَعَبْدِ اللَّهِ بْنِ حُبْشِيٍّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ سُفْيَانُ الثَّوْرِيُّ عَنْ مَنْصُورِ بْنِ الْمُعْتَمِرِ نَحْوَ هَذَا ‏.‏\hadithno{1590}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Abbas: That on the day of Conquest of Makkah, the Messenger of Allah (ﷺ) said: "There is no Hijrah after the conquest, there is only Jihad and intention, and when you are called to go forth (for battle), then go." [He said:] There are narrations on this topic from Abu Sa'eed, 'Abdullah bin 'Amr, and 'Abdullah bin Hubshi. [Abu 'Eisa said:] This Hadith is Hasan Sahih. Sufyan Ath-Thawri reported it similarly from Mansur bin Al-Mu'tamir}}
\hadithdefcmd{tirmidhi}{1591}{حَدَّثَنَا سَعِيدُ بْنُ يَحْيَى بْنِ سَعِيدٍ الأُمَوِيُّ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، فِي قَوْلِهِ تَعَالَى‏:‏ ‏(‏لَقَدْ رَضِيَ اللَّهُ عَنِ الْمُؤْمِنِينَ إِذْ يُبَايِعُونَكَ تَحْتَ الشَّجَرَةِ ‏)‏ قَالَ جَابِرٌ بَايَعْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى أَنْ لاَ نَفِرَّ وَلَمْ نُبَايِعْهُ عَلَى الْمَوْتِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سَلَمَةَ بْنِ الأَكْوَعِ وَابْنِ عُمَرَ وَعُبَادَةَ وَجَرِيرِ بْنِ عَبْدِ اللَّهِ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ عِيسَى بْنِ يُونُسَ عَنِ الأَوْزَاعِيِّ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ قَالَ قَالَ جَابِرُ بْنُ عَبْدِ اللَّهِ وَلَمْ يُذْكَرْ فِيهِ أَبُو سَلَمَةَ ‏.‏\hadithno{1591}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Yahya bin Abi Kathir: From Abu Salamah, from Jabir bin Abdullah about the statement of Allah, most High: Allah was pleased with the believers when they gave the pledge to you under the tree (48:18). that Jabir said: "We pledged to the Messenger of Allah (ﷺ) that we would not flee, and we did not pledge to him for death." [He said:] There are narration on this topic from Salamah bin Al-Akwa', Ibn 'Umar, 'Ubadah, and Jarir bin 'Abdullah. [Abu 'Eisa said:] This Hadith is been reported from 'Eisa bin Yunus, from Al-Awza'i, from Yahya bin Abi Kathir who said: "Jabir bin 'Abdullah said" and he did not mention Abu Salamah on it}}
\hadithdefcmd{tirmidhi}{1592}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، قَالَ قُلْتُ لِسَلَمَةَ بْنِ الأَكْوَعِ عَلَى أَىِّ شَيْءٍ بَايَعْتُمْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَوْمَ الْحُدَيْبِيَةِ قَالَ عَلَى الْمَوْتِ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1592}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Yazid bin Abi 'Ubaid: "I said to Salamah bin Al-Akwa': "For what did you pledge to the Messenger of Allah (ﷺ) on the Day of Al-Hudaibiyyah?" He said: "For death." This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1593}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ كُنَّا نُبَايِعُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى السَّمْعِ وَالطَّاعَةِ فَيَقُولُ لَنَا ‏ "‏ فِيمَا اسْتَطَعْتُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ كِلاَهُمَا ‏.‏\hadithno{1593}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Ibn 'Umar: "We used to pledge to the Messenger of Allah (ﷺ) to hear and obey." So he would say to us: "As much as you are able." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1594}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ لَمْ نُبَايِعْ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى الْمَوْتِ إِنَّمَا بَايَعْنَاهُ عَلَى أَنْ لاَ نَفِرَّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَمَعْنَى كِلاَ الْحَدِيثَيْنِ صَحِيحٌ قَدْ بَايَعَهُ قَوْمٌ مِنْ أَصْحَابِهِ عَلَى الْمَوْتِ وَإِنَّمَا قَالُوا لاَ نَزَالُ بَيْنَ يَدَيْكَ حَتَّى نُقْتَلَ وَبَايَعَهُ آخَرُونَ فَقَالُوا لاَ نَفِرُّ ‏.‏\hadithno{1594}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Jabir bin ‘Abdullah : "We did not pledge to the Messenger of Allah (ﷺ) for death, but only that we would not flee." [Abu 'Eisa said:] This Hadith is Hasan Sahih, meaning both of the Ahadith are Sahih. Some of his Companions pledged to him for death, they said only: "We will not leave from in front of you as long as we are not killed." While others pledged him by saying: "We will not flee}}
\hadithdefcmd{tirmidhi}{1595}{حَدَّثَنَا أَبُو عَمَّارٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثَةٌ لاَ يُكَلِّمُهُمُ اللَّهُ يَوْمَ الْقِيَامَةِ وَلاَ يُزَكِّيهِمْ وَلَهُمْ عَذَابٌ أَلِيمٌ رَجُلٌ بَايَعَ إِمَامًا فَإِنْ أَعْطَاهُ وَفَى لَهُ وَإِنْ لَمْ يُعْطِهِ لَمْ يَفِ لَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَعَلَى ذَلِكَ الْأَمْرُ بِلَا اخْتِلَافٍ.‏\hadithno{1595}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ) said: "Three will not be spoken to by Allah on the Day of Judgement, nor will they be purified, and for them is a painful torment: A man that gave a pledge to an Imam, and if he gives to him he fulfills it, and if he does not give to him he does not fulfill not fulfill it." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1596}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّهُ قَالَ جَاءَ عَبْدٌ فَبَايَعَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى الْهِجْرَةِ وَلاَ يَشْعُرُ النَّبِيُّ صلى الله عليه وسلم أَنَّهُ عَبْدٌ فَجَاءَ سَيِّدُهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ بِعْنِيهِ ‏"‏ ‏.‏ فَاشْتَرَاهُ بِعَبْدَيْنِ أَسْوَدَيْنِ وَلَمْ يُبَايِعْ أَحَدًا بَعْدُ حَتَّى يَسْأَلَهُ أَعَبْدٌ هُوَ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ أَبِي الزُّبَيْرِ ‏.‏\hadithno{1596}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Jabir: "A slave came to give the pledge to the Prophet (ﷺ) for Hijrah, but the Prophet (ﷺ) did not realize that he was a slave. So his master came, and the Prophet (ﷺ) said: 'Sell him to me.' So he purchased him for two black slaves. After this he (ﷺ) would not take the pledge from anyone until he asked him if he was a slave." [He said:] There is something on this topic from Ibn 'Abbas. [Abu 'Eisa said:] The Hadith of Jabir is Hasan Gharib Sahih, we do not know of it except as a narration of Abu Az-Zubair}}
\hadithdefcmd{tirmidhi}{1597}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ الْمُنْكَدِرِ، سَمِعَ أُمَيْمَةَ بِنْتَ رُقَيْقَةَ، تَقُولُ بَايَعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي نِسْوَةٍ فَقَالَ لَنَا ‏"‏ فِيمَا اسْتَطَعْتُنَّ وَأَطَقْتُنَّ ‏"‏ ‏.‏ قُلْتُ اللَّهُ وَرَسُولُهُ أَرْحَمُ بِنَا مِنَّا بِأَنْفُسِنَا ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ بَايِعْنَا ‏.‏ قَالَ سُفْيَانُ تَعْنِي صَافِحْنَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا قَوْلِي لِمِائَةِ امْرَأَةٍ كَقَوْلِي لاِمْرَأَةٍ وَاحِدَةٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَعَبْدِ اللَّهِ بْنِ عُمَرَ وَأَسْمَاءَ بِنْتِ يَزِيدَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ مُحَمَّدِ بْنِ الْمُنْكَدِرِ ‏.‏ وَرَوَى سُفْيَانُ الثَّوْرِيُّ وَمَالِكُ بْنُ أَنَسٍ وَغَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ نَحْوَهُ ‏.‏ قَالَ وَسَأَلْتُ مُحَمَّدًا عَنْ هَذَا الْحَدِيثِ فَقَالَ لاَ أَعْرِفُ لأُمَيْمَةَ بِنْتِ رُقَيْقَةَ غَيْرَ هَذَا الْحَدِيثِ ‏.‏ وَأُمَيْمَةُ امْرَأَةٌ أُخْرَى لَهَا حَدِيثٌ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1597}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Al-Munkadir heard Umaimah bin Ruqaiqah saying:"I pledged to the Messenger of Allah (ﷺ) along with some women. He said to us: 'In as much as you are able and capable.' I said: 'Allah and His Messenger are more merciful to us than we are to ourselves,' then I said: 'O Messenger of Allah take the pledge from us.'" - Sufyan (one of the narrators) said: meaning: 'shake (hands) on it with us' - "so the Messenger of Allah (ﷺ) said: 'My statement to one hundred women is like my statement to one.'" [He said:] There are narrations on this topic from 'Aishah, from 'Abdullah bin 'Umar, and Asma' bint Yazid. [Abu 'Eisa said:] This Hadith is Hasan Sahih, we do not know of it except as a narration of Muhammad bin Al-Munkadir. Sufyan Ath-Thawri, Malik bin Anas, and others reported this Hadith from Muhammad bin Al-Munkadir similarly. He said: I asked Muhammad about this Hadith and he said: "I am not aware of a Hadith other than this from Umaimah bint Ruqaiqah." There is another woman named Umaimah who narrated from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{tirmidhi}{1598}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى الْكُوفِيُّ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ كُنَّا نَتَحَدَّثُ أَنَّ أَصْحَابَ، بَدْرٍ يَوْمَ بَدْرٍ كَعِدَّةِ أَصْحَابِ طَالُوتَ ثَلاَثِمِائَةٍ وَثَلاَثَةَ عَشَرَ رَجُلاً ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ الثَّوْرِيُّ وَغَيْرُهُ عَنْ أَبِي إِسْحَاقَ ‏.‏\hadithno{1598}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Al-Bara' : "We used to say that the participants of Badr on the Day of Badr were like the number of companions of Talut, three hundred and thirteen men." [He said:] There is something on this topic from Ibn 'Abbas. [Abu 'Eisa said:] This Hadith is Hasan Sahih. Ath-Thawri and others reported it from Abu Ishaq}}
\hadithdefcmd{tirmidhi}{1599}{\hadithno{1599}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1600}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، رَافِعِ بْنِ خَدِيجٍ قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَتَقَدَّمَ سَرَعَانُ النَّاسِ فَتَعَجَّلُوا مِنَ الْغَنَائِمِ فَاطَّبَخُوا وَرَسُولُ اللَّهِ صلى الله عليه وسلم فِي أُخْرَى النَّاسِ فَمَرَّ بِالْقُدُورِ فَأَمَرَ بِهَا فَأُكْفِئَتْ ثُمَّ قَسَمَ بَيْنَهُمْ فَعَدَلَ بَعِيرًا بِعَشْرِ شِيَاهٍ ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى سُفْيَانُ الثَّوْرِيُّ، عَنْ أَبِيهِ، عَنْ عَبَايَةَ، عَنْ جَدِّهِ، رَافِعِ بْنِ خَدِيجٍ وَلَمْ يَذْكُرْ فِيهِ أَبِيهِ ‏.‏ حَدَّثَنَا بِذَلِكَ، مَحْمُودُ بْنُ غَيْلاَنَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، ‏.‏ وَهَذَا أَصَحُّ وَعَبَايَةُ بْنُ رِفَاعَةَ سَمِعَ مِنْ، جَدِّهِ رَافِعِ بْنِ خَدِيجٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ ثَعْلَبَةَ بْنِ الْحَكَمِ، وَأَنَسٍ، وَأَبِي، رَيْحَانَةَ وَأَبِي الدَّرْدَاءِ وَعَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ وَزَيْدِ بْنِ خَالِدٍ وَجَابِرٍ وَأَبِي هُرَيْرَةَ وَأَبِي أَيُّوبَ ‏.‏\hadithno{1600}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Abayah bin Rifa'ah: From his father, from his grandfather Rafi' bin Khadij, who said: "We were with the Messenger of Allah (ﷺ) on a journey, when the hasty people went rushing ahead to the sheep to cook them, while the Messenger of Allah (ﷺ) was in the rear of the people. Then he passed the kettled and ordered that they be weighed, then he distributed it between them and equated a camel to ten sheep." [Abu 'Eisa said:] Sufyan Ath-Thawri reported it from his father, from 'Abayah, from his grandfather Rafi' bin Khadij, and he did not mention "from his father" in it. This was narrated to us by Mahmud bin Ghailan (who said:) "Waki' narrated it to us from Sufyan." And this is more correct. 'Abayah bin Rifa'ah heard from his grandfather Rafi' bin Khadij. He said: There are narrations on this topic from Tha'labah bin Al-Hakam, Anas, Abu Rihanah, Abu Ad-Darda, 'Abdur-Rahman bin Samurah, Zaid bin Khalid, Jabir, Abu Hurairah, and Abu Ayyub}}
\hadithdefcmd{tirmidhi}{1601}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ انْتَهَبَ فَلَيْسَ مِنَّا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ أَنَسٍ ‏.‏\hadithno{1601}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas: That the Messenger of Allah (ﷺ) said: "Whoever plunders then he is not of us." [Abu 'Eisa said:] This Hadith is Hasan Sahih Gharib as a Hadith of Anas}}
\hadithdefcmd{tirmidhi}{1602}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَبْدَءُوا الْيَهُودَ وَالنَّصَارَى بِالسَّلاَمِ وَإِذَا لَقِيتُمْ أَحَدَهُمْ فِي الطَّرِيقِ فَاضْطَرُّوهُمْ إِلَى أَضْيَقِهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَأَنَسٍ وَأَبِي بَصْرَةَ الْغِفَارِيِّ صَاحِبِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَمَعْنَى هَذَا الْحَدِيثِ ‏"‏ لاَ تَبْدَءُوا الْيَهُودَ وَالنَّصَارَى ‏"‏ ‏.‏ قَالَ بَعْضُ أَهْلِ الْعِلْمِ إِنَّمَا مَعْنَى الْكَرَاهِيَةِ لأَنَّهُ يَكُونُ تَعْظِيمًا لَهُ وَإِنَّمَا أُمِرَ الْمُسْلِمُونَ بِتَذْلِيلِهِمْ وَكَذَلِكَ إِذَا لَقِيَ أَحَدَهُمْ فِي الطَّرِيقِ فَلاَ يَتْرُكُ الطَّرِيقَ عَلَيْهِ لأَنَّ فِيهِ تَعْظِيمًا لَهُمْ ‏.‏\hadithno{1602}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ) said: "Do not precede the Jews and the Christians with the Salam. And if one you meets one of them in the path, then force him to its narrow portion." [He said:] There are narrations on this topic from Ibn 'Umar, Anas, and Abu Basrah Al-Ghifari the Companion of the Prophet (ﷺ). [Abu 'Eisa said:] This Hadith is Hasan Sahih. And regarding the meaning of this Hadith: "Do not precede the Jews and the Christians": Some of the poeple of knowledge said that it only means that it is disliked because it would be honoring them, and the Muslims were ordered to humiliate them. For this reason, when one of them is met on the path, then the path is not yielded for him, because doing so would amount to honoring them}}
\hadithdefcmd{tirmidhi}{1603}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْيَهُودَ إِذَا سَلَّمَ عَلَيْكُمْ أَحَدُهُمْ فَإِنَّمَا يَقُولُ السَّامُ عَلَيْكُمْ فَقُلْ عَلَيْكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1603}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Umar: That the Messenger of Allah (ﷺ) said: "Indeed when a Jew gives Salam to one of you, then he is only saying: 'As-Samu 'Alaikum' (Death be upon you) so say: "Alaik (And upon you).'" [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1604}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ سَرِيَّةً إِلَى خَثْعَمٍ فَاعْتَصَمَ نَاسٌ بِالسُّجُودِ فَأَسْرَعَ فِيهِمُ الْقَتْلُ فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَأَمَرَ لَهُمْ بِنِصْفِ الْعَقْلِ وَقَالَ ‏"‏ أَنَا بَرِيءٌ مِنْ كُلِّ مُسْلِمٍ يُقِيمُ بَيْنَ أَظْهُرِ الْمُشْرِكِينَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَلِمَ قَالَ ‏"‏ لاَ تَرَايَا نَارَاهُمَا ‏"‏ ‏.‏\hadithno{1604}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Qais bin Abu Hazim: From Jarir bin 'Abdullah that the Messenger of Allah (ﷺ) sent a military expedition to Khath'am. So some people (living there) sought safety by prostrating, but they were met quickly and killed. News of this reached the Prophet (ﷺ) upon which he commanded that they be given half of the 'Aql (blood money). And he said: "I am free from every Muslim that lives among the idolaters." They said:"O Messenger of Allah: How is that ?" He said: "They should not see each other's campfires}}
\hadithdefcmd{tirmidhi}{1605}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، مِثْلَ حَدِيثِ أَبِي مُعَاوِيَةَ وَلَمْ يَذْكُرْ فِيهِ عَنْ جَرِيرٍ، ‏.‏ وَهَذَا أَصَحُّ ‏.‏ وَفِي الْبَابِ عَنْ سَمُرَةَ، ‏.‏ قَالَ أَبُو عِيسَى وَأَكْثَرُ أَصْحَابِ إِسْمَاعِيلَ قَالُوا عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ سَرِيَّةً وَلَمْ يَذْكُرُوا فِيهِ عَنْ جَرِيرٍ.‏ وَرَوَاهُ حَمَّادُ بْنُ سَلَمَةَ عَنْ الْحَجَّاجِ بْنِ أَرْطَاةَ عَنْ إِسْمَعِيلَ بْنِ أَبِي خَالِدٍ عَنْ قَيْسٍ عَنْ جَرِيرٍ مِثْلَ حَدِيثِ أَبِي مُعَاوِيَةَ قَالَ وَسَمِعْت مُحَمَّدًا يَقُولُ الصَّحِيحُ حَدِيثُ قَيْسٍ عَنْ النَّبِيِّ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ مُرْسَلٌ وَرَوَى سَمُرَةُ بْنُ جُنْدَبٍ عَنْ النَّبِيِّ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ قَالَ لَا تُسَاكِنُوا الْمُشْرِكِينَ وَلَا تُجَامِعُوهُمْ فَمَنْ سَاكَنَهُمْ أَوْ جَامَعَهُمْ فَهُوَ مِثْلُهُمْ\hadithno{1605}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{Narrated Qais bin Abu Hazim: Similar to the narration of Abu Mu'aqiyah (no. 1604) but he did not mention in it: "from Jarir" in it, and that is more correct. There is something on this topic from Samurah. [Abu 'Eisa said:] Most of the companions of Isma'il said: "From Isma'il, from Qais bin Abu Hazim, that the Messenger of Allah (ﷺ) sent a military expedition." and they did not mention: "from Jarir" in it. Hammad bin Salamah reported similar to the narration of Abu Mu'awiyah, from Al-Hajjaj bin Artah, from Isma'il bin Abi Khalid, from Qais from Jarir [He said:] I heard Muhammad saying: "What is correct is the narration of Qais from the Prophet (ﷺ) in Mursal form." Samurah bin Jundab repoted that the Prophet (ﷺ) said: "Do not live among the idolaters, and do not assemble with them, for whoever lives among them or assembles with them then he is similar to them}}
\hadithdefcmd{tirmidhi}{1606}{حَدَّثَنَا مُوسَى بْنُ عَبْدِ الرَّحْمَنِ الْكِنْدِيُّ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، أَخْبَرَنَا سُفْيَانُ الثَّوْرِيُّ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَئِنْ عِشْتُ إِنْ شَاءَ اللَّهُ لأُخْرِجَنَّ الْيَهُودَ وَالنَّصَارَى مِنْ جَزِيرَةِ الْعَرَبِ ‏"‏ ‏.‏\hadithno{1606}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated 'Umar bin Al-Khattab:That the Messenger of Allah (ﷺ) said: "If I live - if Allah wills - I will expel the Jews and the Christians from the Arabian Peninsula}}
\hadithdefcmd{tirmidhi}{1607}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا أَبُو عَاصِمٍ، وَعَبْدُ الرَّزَّاقِ، قَالاَ أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ أَخْبَرَنِي عُمَرُ بْنُ الْخَطَّابِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لأُخْرِجَنَّ الْيَهُودَ وَالنَّصَارَى مِنْ جَزِيرَةِ الْعَرَبِ فَلاَ أَتْرُكُ فِيهَا إِلاَّ مُسْلِمًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1607}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Jabir bin ‘Abdullah : "Umar bin Al-Khattab informed me that he heard the Messenger of Allah (ﷺ) say: 'I will expel the Jews and the Christians from the Arabian Peninsula, and I will not leave anyone in it except a Muslim." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1608}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَتْ فَاطِمَةُ إِلَى أَبِي بَكْرٍ فَقَالَتْ مَنْ يَرِثُكَ قَالَ أَهْلِي وَوَلَدِي ‏.‏ قَالَتْ فَمَا لِي لاَ أَرِثُ أَبِي فَقَالَ أَبُو بَكْرٍ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ نُورَثُ ‏"‏ ‏.‏ وَلَكِنِّي أَعُولُ مَنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَعُولُهُ وَأُنْفِقُ عَلَى مَنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُنْفِقُ عَلَيْهِ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عُمَرَ وَطَلْحَةَ وَالزُّبَيْرِ وَعَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَسَعْدٍ وَعَائِشَةَ ‏.‏ وَحَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ إِنَّمَا أَسْنَدَهُ حَمَّادُ بْنُ سَلَمَةَ وَعَبْدُ الْوَهَّابِ بْنُ عَطَاءٍ عَنْ مُحَمَّدِ بْنِ عَمْرٍو عَنْ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ ‏.‏ وَسَأَلْتُ مُحَمَّدًا عَنْ هَذَا الْحَدِيثِ فَقَالَ لاَ أَعْلَمُ أَحَدًا رَوَاهُ عَنْ مُحَمَّدِ بْنِ عَمْرٍو عَنْ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ إِلاَّ حَمَّادَ بْنَ سَلَمَةَ ‏.‏ وَرَوَى عَبْدُ الْوَهَّابِ بْنُ عَطَاءٍ عَنْ مُحَمَّدِ بْنِ عَمْرٍو عَنْ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ نَحْوَ رِوَايَةِ حَمَّادِ بْنِ سَلَمَةَ ‏.‏\hadithno{1608}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah: "Fatimah came to Abu Bakr and said: 'Who will inherit from you?' He said: 'My family and my son.' She said: 'So what about me? I do not get inheritance from my father?' So Abu Bakr said: 'I heard the Messenger of Allah (ﷺ) say: 'We are not inherited from' but I support those whom the Messenger of Allah (ﷺ) used to support, and I spend upon those whom the Messenger of Allah (ﷺ) spent upon." [Abu 'Eisa said:] There are narrations on this topic from 'Umar, Talhah, Az-Zubair, 'Abdur-Rahman bin 'Awf, Sa'd and 'Aishah. The Hadith of Abu Hurairah is Hasan Gharib from this route. It is only reported with a chain by Hammad bin Salamah and 'Abdul Wahhab bin 'Ata, from Muhammad bin 'Amr, from Abu Salamah, from Abu Hurairah. I asked Muhammad about this Hadith and he said: "No one is known to have reported it from Muhammad bin 'Amr, from Abu Salamah, from Abu Hurairah except from Hammad bin Salamah. 'Abdul Wahhab bin 'Ata reported it from Muhammad bib 'Amr, from Abu Salamah, and from Abu Hurairah and it is similar to the narration of Hammad bin Salamah. And this Hadith has been reported through other routes from Abu Bakr As-Siddiq, from the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{1609}{حَدَّثَنَا بِذَلِكَ، عَلِيُّ بْنُ عِيسَى الْبَغْدَادِيُّ قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَطَاءٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ فَاطِمَةَ، جَاءَتْ أَبَا بَكْرٍ وَعُمَرَ رضى الله عنهما تَسْأَلُ مِيرَاثَهَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالاَ سَمِعْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنِّي لاَ أُورَثُ ‏"‏ ‏.‏ قَالَتْ وَاللَّهِ لاَ أُكَلِّمُكُمَا أَبَدًا ‏.‏ فَمَاتَتْ وَلاَ تُكَلِّمُهُمَا ‏.‏ قَالَ عَلِيُّ بْنُ عِيسَى مَعْنَى لاَ أُكَلِّمُكُمَا تَعْنِي فِي هَذَا الْمِيرَاثِ أَبَدًا أَنْتُمَا صَادِقَانِ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي بَكْرٍ الصِّدِّيقِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1609}\hadithgrade{Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah: That Fatimah came to Abu Bakr and 'Umar may Allah be pleased with them both, to ask them about her inheritance from the Messenger of Allah (ﷺ). They said: "We heard the Messenger of Allah (ﷺ) say: 'I am not inherited from.'" So she said: 'By Allah! I will never talk to you two again.' So she died having not talked to them." 'Ali bin 'Eisa said: "The meaning of not speaking to you two is: 'Never again regarding this inheritance, because you two are truthful}}
\hadithdefcmd{tirmidhi}{1610}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، أَخْبَرَنَا بِشْرُ بْنُ عُمَرَ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنِ ابْنِ شِهَابٍ، عَنْ مَالِكِ بْنِ أَوْسِ بْنِ الْحَدَثَانِ، قَالَ دَخَلْتُ عَلَى عُمَرَ بْنِ الْخَطَّابِ وَدَخَلَ عَلَيْهِ عُثْمَانُ بْنُ عَفَّانَ وَالزُّبَيْرُ بْنُ الْعَوَّامِ وَعَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ وَسَعْدُ بْنُ أَبِي وَقَّاصٍ ثُمَّ جَاءَ عَلِيٌّ وَالْعَبَّاسُ يَخْتَصِمَانِ فَقَالَ عُمَرُ لَهُمْ أَنْشُدُكُمْ بِاللَّهِ الَّذِي بِإِذْنِهِ تَقُومُ السَّمَاءُ وَالأَرْضُ تَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ نُورَثُ مَا تَرَكْنَاهُ صَدَقَةٌ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ عُمَرُ فَلَمَّا تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ أَبُو بَكْرٍ أَنَا وَلِيُّ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَجِئْتَ أَنْتَ وَهَذَا إِلَى أَبِي بَكْرٍ تَطْلُبُ أَنْتَ مِيرَاثَكَ مِنَ ابْنِ أَخِيكَ وَيَطْلُبُ هَذَا مِيرَاثَ امْرَأَتِهِ مِنْ أَبِيهَا فَقَالَ أَبُو بَكْرٍ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ نُورَثُ مَا تَرَكْنَاهُ صَدَقَةٌ ‏"‏ ‏.‏ وَاللَّهُ يَعْلَمُ إِنَّهُ لَصَادِقٌ بَارٌّ رَاشِدٌ تَابِعٌ لِلْحَقِّ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْحَدِيثِ قِصَّةٌ طَوِيلَةٌ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ مَالِكِ بْنِ أَنَسٍ ‏.‏\hadithno{1610}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Malik bin Aws bin Al-Hadathan: "I entered upon 'Umar bin Al-Khattab. (Then) Uthman bin 'Affan, Az-Zubair, 'Abdur-Rahman bin Awf, and Sa'd bin Abi Waqqas entered. Then 'Ali and Al-'Abbas came disputing. 'Umar said to them: ' I ask you, by Allah the One by Whose Will the heavens and the earth are maintained, do you know that the Messenger of Allah (ﷺ) said: "We are not inherited from, what we leave is charity?" They said: 'Yes.' 'Umar said: 'When the Messenger of Allah (ﷺ) died, Abu Bakr said: "I am the caretaker of the Messenger of Allah (ﷺ)" So you and he went to Abu Bakr and you sought your inheritance from the son of your brother, and he sought the inheritance of his wife from her father. So Abu Bakr said that the Messenger of Allah (ﷺ) said: "We are not inherited from, what we leave is charity." And Allah knows that he is truthful, innocent, instructing and following the truth.'" [Abu 'Eisa said:] There is a lengthy story along with the Hadith. And this Hadith is Hasan Sahih Gharib as a narration of Malik bin Anas}}
\hadithdefcmd{tirmidhi}{1611}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا زَكَرِيَّا بْنُ أَبِي زَائِدَةَ، عَنِ الشَّعْبِيِّ، عَنِ الْحَارِثِ بْنِ مَالِكِ بْنِ الْبَرْصَاءِ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَوْمَ فَتْحِ مَكَّةَ يَقُولُ ‏ "‏ لاَ تُغْزَى هَذِهِ بَعْدَ الْيَوْمِ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَسُلَيْمَانَ بْنِ صُرَدٍ وَمُطِيعٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَهُوَ حَدِيثُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ عَنِ الشَّعْبِيِّ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِهِ ‏.‏\hadithno{1611}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Al-Harith bin Malik bin Al-Barsa': "On the day of the Conquest of Makkah, I heard the Prophet (ﷺ) saying: 'This is not to be battled over after today, until the Day of Judgement.'" [Abu 'Eisa said:] There are narrations on this topic from Ibn 'Abbas, Sulaiman bin Surad, and Muti' This Hadith is Hasan Sahih, and it is a narration of Zakariyya bin Abi Za'idah from Ash-Sha'bi, we do not know of it except from his narration}}
\hadithdefcmd{tirmidhi}{1612}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنِ النُّعْمَانِ بْنِ مُقَرِّنٍ، قَالَ غَزَوْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فَكَانَ إِذَا طَلَعَ الْفَجْرُ أَمْسَكَ حَتَّى تَطْلُعَ الشَّمْسُ فَإِذَا طَلَعَتْ قَاتَلَ فَإِذَا انْتَصَفَ النَّهَارُ أَمْسَكَ حَتَّى تَزُولَ الشَّمْسُ فَإِذَا زَالَتِ الشَّمْسُ قَاتَلَ حَتَّى الْعَصْرِ ثُمَّ أَمْسَكَ حَتَّى يُصَلِّيَ الْعَصْرَ ثُمَّ يُقَاتِلُ ‏.‏ قَالَ وَكَانَ يُقَالُ عِنْدَ ذَلِكَ تَهِيجُ رِيَاحُ النَّصْرِ وَيَدْعُو الْمُؤْمِنُونَ لِجُيُوشِهِمْ فِي صَلاَتِهِمْ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنِ النُّعْمَانِ بْنِ مُقَرِّنٍ بِإِسْنَادٍ أَوْصَلَ مِنْ هَذَا ‏.‏ وَقَتَادَةُ لَمْ يُدْرِكِ النُّعْمَانَ بْنَ مُقَرِّنٍ وَمَاتَ النُّعْمَانُ بْنُ مُقَرِّنٍ فِي خِلاَفَةِ عُمَرَ ‏.‏\hadithno{1612}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated An-Nu'man bin Muqarrin : "I fought along with the Prophet (ﷺ), and if Fajr had begun he would wait until the sun rose, and when it rose he would fight. And if it was the middle of the daytime, he would wait until the sun passed the zenit, and when it passed the zenith he would fight until 'Asr. Then he would wait until he prayed 'Asr, then he would fight." He said: "And it is used to be said during that (time) the the wind of victory was raging, and the believers would supplicate for their armies in their Salat." [Abu 'Eisa said:] This Hadith has been reported from An-Nu'man bin Muqarrin through a chain that is more connected that this. Qatadah did not see An-Nu'man bin Muqarrin. An-Nu'man died during the Khilafah of 'Umar}}
\hadithdefcmd{tirmidhi}{1613}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ، وَالْحَجَّاجُ بْنُ مِنْهَالٍ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، حَدَّثَنَا أَبُو عِمْرَانَ الْجَوْنِيُّ، عَنْ عَلْقَمَةَ بْنِ عَبْدِ اللَّهِ الْمُزَنِيِّ، عَنْ مَعْقِلِ بْنِ يَسَارٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، بَعَثَ النُّعْمَانَ بْنَ مُقَرِّنٍ إِلَى الْهُرْمُزَانِ فَذَكَرَ الْحَدِيثَ بِطُولِهِ فَقَالَ النُّعْمَانُ بْنُ مُقَرِّنٍ شَهِدْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَكَانَ إِذَا لَمْ يُقَاتِلْ أَوَّلَ النَّهَارِ انْتَظَرَ حَتَّى تَزُولَ الشَّمْسُ وَتَهُبَّ الرِّيَاحُ وَيَنْزِلَ النَّصْرُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَعَلْقَمَةُ بْنُ عَبْدِ اللَّهِ هُوَ أَخُو بَكْرِ بْنِ عَبْدِ اللَّهِ الْمُزَنِيِّ ‏.‏\hadithno{1613}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ma'qil bin Yasar: "Umar bin Al-Khattab sent An-Nu'man bin Muqarrin to Al-Hurmuzan." And he mentioned the Hadith in its entirety. An-Nu'man bin Muqarrin said: "I participated (in battles) with the Messenger of Allah (ﷺ). So when he did not fight in the beginning if the daytime, he would wait until the sun passed the zenith, and the wind of victory would rage, and victory would descent upon them." [Abu 'Eisa said:] This Hadith is Hasan Sahih. 'Alqamah bin 'Abdullah (one of the narrators) is the brother of Bakr bin 'Abdullah Al-Muzani}}
\hadithdefcmd{tirmidhi}{1614}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ عِيسَى بْنِ عَاصِمٍ، عَنْ زِرٍّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الطِّيَرَةُ مِنَ الشِّرْكِ ‏"‏ ‏.‏ وَمَا مِنَّا إِلاَّ وَلَكِنَّ اللَّهَ يُذْهِبُهُ بِالتَّوَكُّلِ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَحَابِسٍ التَّمِيمِيِّ وَعَائِشَةَ وَابْنِ عُمَرَ وَسَعْدٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ سَلَمَةَ بْنِ كُهَيْلٍ وَرَوَى شُعْبَةُ أَيْضًا عَنْ سَلَمَةَ هَذَا الْحَدِيثَ ‏.‏ قَالَ سَمِعْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ يَقُولُ كَانَ سُلَيْمَانُ بْنُ حَرْبٍ يَقُولُ فِي هَذَا الْحَدِيثِ ‏"‏ وَمَا مِنَّا إِلاَّ وَلَكِنَّ اللَّهَ يُذْهِبُهُ بِالتَّوَكُّلِ ‏"‏ ‏.‏ قَالَ سُلَيْمَانُ هَذَا عِنْدِي قَوْلُ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَمَا مِنَّا‏.‏\hadithno{1614}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Abdullah bin Mas'ud: That the Messenger of Allah (ﷺ) said: "At-Tiyarah is from Shirk, and none among us (it influences) except that Allah will remove it with Tawakkul (reliance)." [Abu 'Eisa said:] I heard Muhammad bin Isma'il saying: "Sulaiman bin Harb used to say about this Hadith: 'And none among us (it influences) except that Allah will remove it with Tawakkul (reliance)' - Sulaiman would say: 'To me, this is a saying of 'Abdullah bin Mas'ud.'" There are narrations on this topic from Sa'd, Abu Hurairah, Habis At-Tamimi, 'Aishah and Ibn 'Umar. This Hadith is Hasan Sahih, we do not know of it except as a narration of Salamah bin Khuail. Shu'bah also reported this Hadith from Salamah}}
\hadithdefcmd{tirmidhi}{1615}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ عَدْوَى وَلاَ طِيَرَةَ وَأُحِبُّ الْفَأْلَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَمَا الْفَأْلُ قَالَ ‏"‏ الْكَلِمَةُ الطَّيِّبَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1615}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas: That the Messenger of Allah (ﷺ) said: "There is no 'Adwa and no Tiyarah, and I like Fa'l." They said: "O Messenger of Allah! What is Fa'l?" He said: "A good statement." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1616}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ حُمَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُعْجِبُهُ إِذَا خَرَجَ لِحَاجَةٍ أَنْ يَسْمَعَ يَا رَاشِدُ يَا نَجِيحُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏\hadithno{1616}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas bin Malik: That the Prophet (ﷺ) used to like it when he set out upon an affair if he heard: "O directed one, O successful one." [Abu 'Eisa said:] This Hadith is Hasan Sahih Gharib}}
\hadithdefcmd{tirmidhi}{1617}{\hadithno{1617}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1618}{\hadithno{1618}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
